@@ -1,37 +1,35 @@
-## ----setup, include=FALSE------------------------------------------------
+## ---- include = FALSE----------------------------------------------------
+knitr::opts_chunk$set(
+  collapse = TRUE,
+  comment = "#>"
+)
+
 library(dplyr)
 library(tidypredict)
+library(parsnip)
 library(ranger)
 set.seed(100)
 
 ## ------------------------------------------------------------------------
-library(ranger)
-model <- ranger::ranger(Species ~ .,data = iris ,num.trees = 100)
-
-## ------------------------------------------------------------------------
+library(dplyr)
 library(tidypredict)
+library(ranger)
 
-tidypredict_sql(model, dbplyr::simulate_mssql())
+model <- ranger(Species ~ .,data = iris, num.trees =  100)
 
 ## ------------------------------------------------------------------------
-iris %>%
-  tidypredict_to_column(model) %>%
-  head(10)
+treeInfo(model) %>%
+  head()
 
 ## ------------------------------------------------------------------------
-treeInfo(model)
+tidypredict_fit(model)[1]
 
 ## ------------------------------------------------------------------------
-parse_model(model)
+library(parsnip)
 
-## ------------------------------------------------------------------------
-tidypredict_fit(model)
+parsnip_model <- rand_forest() %>%
+  set_engine("ranger") %>%
+  fit(Species ~ ., data = iris)
 
-## ------------------------------------------------------------------------
-test <- tidypredict_test(model, iris, threshold = 4)
-
-test
-
-test$raw_results %>%
-  filter(predict != tidypredict)
+tidypredict_fit(parsnip_model)[[1]]
 
